<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Anwendungsproxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy-Typ</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-Adresse</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Optional</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Auswählen von &quot;Proxy benutzen&quot; im Kontextmenü der Anwendung im Starter, um das Programm mit der Proxy-Konfiguration auszuführen.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ungültige IP-Adresse</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Ungültiger Port</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Trennen</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Trennen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Sind Sie sicher, dass Sie diese Konfiguration löschen möchten?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Kabelgebundene Verbindung %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Drahtlosverbindung %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE-Verbindung %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Neues VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN-Typ</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportieren</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Anwendungsproxy</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Persönlicher Hotspot</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Netzwerkdetails</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Systemproxy</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kabelgebundenes Netzwerk</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Drahtlosnetzwerk</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Flugzeugmodus</translation>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Kabelgebundener Netzwerkadapter</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Netzwerkverbindung hinzufügen</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Drahtlosnetzwerkadapter</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Mit verstecktem Netzwerk verbinden</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE-Verbindung erstellen</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN-Status</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN erstellen</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN importieren</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy-Typ</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurations-URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-Adresse</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Hotspot erstellen</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Schnittstelle</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primärer DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netzmaske</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Präfix</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Geschwindigkeit</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Flugzeugmodus</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Ungültige DNS-Adresse</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Nicht gebunden</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Geräte MAC-Adresse</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Geklonte MAC-Adresse</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU anpassen</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Der Name existiert bereits</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Automatisch verbinden</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Einstellungen hinzufügen</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Hotspot erstellen</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP-Adresse</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ungültige IP-Adresse</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Ungültige Netzmaske</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Es ist nur ein Gateway erlaubt</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ungültiger Gateway</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netzmaske</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ungültige IP-Adresse</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Es ist nur ein Gateway erlaubt</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ungültiger Gateway</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Präfix</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorieren</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-Adresse</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>nur für Adressen im VPN verwenden</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Methode</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netzmaske</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Präfix</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ungültige IP-Adresse</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Ungültige Netzmaske</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ungültiger Gateway</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP Konflikt</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Methode</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorieren</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Netzwerkdetails</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Systemproxy</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Anwendungsproxy</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Flugzeugmodus</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Netzwerkdetails</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP Konflikt</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Mit Netzwerkverwaltung konfigurieren</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Persönlicher Hotspot</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Dienst</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP-Authentifizierung ablehnen</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP-Authentifizierung ablehnen</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP-Authentifizierung ablehnen</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP-Authentifizierung ablehnen</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2-Authentifizierung ablehnen</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Keine BSD-Datenkomprimierung</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Keine Deflate-Datenkomprimierung</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Keine TCP-Kopfdatenkomprimierung</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Keine Protokollfeldkomprimierung</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Keine Adress-/Kontrollkomprimierung</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP-Echopakete senden</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE verwenden</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-Bit-MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE mit Zuständen</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE-Verbindung erstellen</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Systemproxy</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy-Typ</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Optional</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP-Proxy</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS-Proxy</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP-Proxy</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS-Proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Proxy-Konfigurationen für die obigen Hosts und Domains ignorieren</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurations-URL</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Sicherheit</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Getunneltes TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Geschütztes EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Passwort für diesen Benutzer speichern</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Passwort für alle Benutzer speichern</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Immer nachfragen</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonym</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Authentifiziert</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Beide</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Version 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Version 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP Auth</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identität</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Passwortoptionen</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privater Schlüssel</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Benutzerzertifikat</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonyme Kennung</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Bereitstellung</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC-Datei</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Innere Auth</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP-Version</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privates Passwort</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Ungültiges Passwort</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sicherheit</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Schlüssel</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Sicherheit erforderlich</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Ungültiges Passwort</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA 3 Personal</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Gemeinsamer Schlüssel</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Offenes System</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sicherheit</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Authentifizierung</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Schlüssel</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Erweitertes VPN</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Gateway-Port anpassen</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Gateway-Port</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Neuverhandlungsintervall anpassen</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Neuverhandlungsintervall</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>LZO-Datenkomprimierung verwenden</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>TCP-Verbindung verwenden</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>TAP-Gerät verwenden</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Tunnel-MTU anpassen</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>UDP-Fragmentgröße anpassen</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP-Fragmentgröße</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Tunnel TCP MSS beschränken</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Entfernte Hosts zufällig auswählen</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Erweitertes VPN</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (Standard)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>NetScreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Sicher (Standard)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Schwach</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T, wenn verfügbar (Standard)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T immer</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH-Gruppe 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH-Gruppe 2 (Standard)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH-Gruppe 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Server (Standard)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH-Gruppe 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domäne</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Hersteller</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Verschlüsselung</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT-Durchdringung</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH-Gruppe</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Vorwärts gerichtete Geheimhaltung</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Lokaler Port</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Erkennung toter Peers deaktivieren</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>IPsec erlauben</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Gruppenname</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Gruppenkennung</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Vorher vereinbarter Schlüssel</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Phase1-Algorithmen</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Phase2-Algorithmen</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ungültiger Gateway</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Cisco Secure Desktop Trojan erlauben</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD-Skript</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Benutzerzertifikat</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privater Schlüssel</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>FSID für Schlüsselpassphrase verwenden</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ungültiger Gateway</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Zertifikate (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Zertifikate mit Passwort (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Statischer Schlüssel</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Gespeichert</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Nachfragen</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nicht erforderlich</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Auth Typ</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Benutzerzertifikat</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privater Schlüssel</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Passwortoptionen</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privates Passwort</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Schlüsselrichtung anpassen</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Schlüsselrichtung</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Entfernte IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Lokale IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Alle verfügbar (Standard)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-Bit (weniger sicher)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-Bit (am sichersten)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP-Authentifizierung ablehnen</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP-Authentifizierung ablehnen</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP-Authentifizierung ablehnen</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP-Authentifizierung ablehnen</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2-Authentifizierung ablehnen</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Keine BSD-Datenkomprimierung</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Keine Deflate-Datenkomprimierung</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Keine TCP-Kopfdatenkomprimierung</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Keine Protokollfeldkomprimierung</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Keine Adress-/Kontrollkomprimierung</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP-Echopakete senden</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE verwenden</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sicherheit</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE mit Zuständen</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN-Status</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN erstellen</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN importieren</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Importfehler</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Dateifehler</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN-Proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nicht erforderlich</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy-Typ</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server-IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Bei Fehlschlag endlos weiterversuchen</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA-Datei</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Zertifikatswarnungen ignorieren</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>TLS-Hostnamenerweiterungen verwenden</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN-Sicherheit</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Verschlüsselungsverfahren</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ungültiger Gateway</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Gespeichert</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Nachfragen</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nicht erforderlich</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Passwortoptionen</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT-Domäne</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN-Proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server-IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ungültiger Gateway</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privater Schlüssel</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH-Agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Chipkarte</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Vorher vereinbarter Schlüssel</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Auth Typ</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Benutzerzertifikat</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Eine innere IP-Adresse anfordern</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>UDP-Verkapselung erzwingen</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>IP-Komprimierung verwenden</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Benutzerdefinierte Verschlüsselungsverfahrenvorschläge aktivieren</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS-Authentifizierung</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Thema Treffer</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Entfernter Cert Typ</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Schlüsseldatei</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Schlüsselrichtung anpassen</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Schlüsselrichtung</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ungültiger Gateway</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Gespeichert</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Nachfragen</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nicht erforderlich</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Passwortoptionen</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Gruppenname</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Gruppenpasswort</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Hybride Authentifizierung verwenden</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA-Datei</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Schließen Sie zuerst das Netzwerkkabel an</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Kabelgebundener Netzwerkadapter</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Netzwerkverbindung hinzufügen</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Einstellungen auswählen</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Drahtlosnetzwerkadapter</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Hotspot schließen</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Deaktivieren Sie zuerst den Hotspot, wenn Sie eine Verbindung zu einem drahtlosen Netzwerk herstellen möchten</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Mit verstecktem Netzwerk verbinden</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Nicht gebunden</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Geräte MAC-Adresse</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU anpassen</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokoll</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Sicherheitstyp</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Schnittstelle</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netzmaske</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primärer DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Präfix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Geschwindigkeit</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Gerät deaktiviert</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbunden, aber kein Internetzugang</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nicht verbunden</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Netzwerkkabel abgezogen</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Wird verbunden</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Wird authentifiziert</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP-Adresse wird abgerufen</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Verbunden</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Getrennt</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP Konflikt</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Fehlgeschlagen</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Adresse wird abgerufen</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Kabelgebundenes Netzwerk</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kabelgebundenes Netzwerk %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Drahtlosnetzwerk</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Drahtlosnetzwerk %1</translation>
    </message>
</context>
</TS>